@@ -1,8 +1,9 @@
 use strict;
 use warnings;
+
+BEGIN { die "DBM is not yet supported!\n" unless $ENV{DBO_ALLOW_DBM} }
 use SQL::Statement;
 
-die "DBM is not yet supported!\n" unless $ENV{DBO_ALLOW_DBM};
 
 package # hide from PAUSE
     DBIx::DBO::DBD::DBM;
@@ -20,7 +21,6 @@ sub _get_table_schema {
     my $me = shift;
     my $schema = shift; # Not used
     my $table = shift;
-    ouch 'No table name supplied' unless defined $table and length $table;
     return;
 }
 
@@ -28,18 +28,17 @@ sub _get_table_info {
     my $me = shift;
     my $schema = shift; # Not used
     my $table = my $q_table = shift;
-    ouch 'No table name supplied' unless defined $table and length $table;
 
-    unless (exists $me->rdbh->{dbm_tables}{$q_table}
-            and exists $me->rdbh->{dbm_tables}{$q_table}{c_cols}
-            and ref $me->rdbh->{dbm_tables}{$q_table}{c_cols} eq 'ARRAY') {
+    unless (exists $me->rdbh->{dbm_tables}{$q_table}) {
         $q_table = $me->_qi($table); # Try with the quoted table name
-        unless (exists $me->rdbh->{dbm_tables}{$q_table}
-                and exists $me->rdbh->{dbm_tables}{$q_table}{c_cols}
-                and ref $me->rdbh->{dbm_tables}{$q_table}{c_cols} eq 'ARRAY') {
+        unless (exists $me->rdbh->{dbm_tables}{$q_table}) {
             ouch 'Invalid table: '.$q_table;
         }
     }
+    unless (exists $me->rdbh->{dbm_tables}{$q_table}{c_cols}
+            and ref $me->rdbh->{dbm_tables}{$q_table}{c_cols} eq 'ARRAY') {
+        ouch 'Invalid DBM table info, could be an incompatible version';
+    }
 
     my %h;
     my $i;
@@ -48,7 +47,7 @@ sub _get_table_info {
     }
     $h{Columns} = [ sort { $h{Column_Idx}{$a} cmp $h{Column_Idx}{$b} } keys %{$h{Column_Idx}} ];
     $h{PrimaryKeys} = [];
-    $me->{TableInfo}{$schema // ''}{$table} = \%h;
+    $me->{TableInfo}{defined $schema ? $schema : ''}{$table} = \%h;
 }
 
 1;
